pub fn dummy_chain_description(index: u32) -> ChainDescriptionExpand description
Creates a dummy chain description with a deterministic single owner and the maximum balance.
pub fn dummy_chain_description(index: u32) -> ChainDescriptionCreates a dummy chain description with a deterministic single owner and the maximum balance.