pub fn dummy_chain_description_with_owner(
index: u32,
owner: AccountOwner,
) -> ChainDescriptionExpand description
Creates a dummy chain description owned by the given owner, with the maximum balance.
pub fn dummy_chain_description_with_owner(
index: u32,
owner: AccountOwner,
) -> ChainDescriptionCreates a dummy chain description owned by the given owner, with the maximum balance.